@@ -1,10 +1,9 @@
 /*
- * Copyright 2005-2008 Gentoo Foundation
+ * Copyright 2005-2014 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/libq/atom_compare.c,v 1.8 2013/04/29 04:38:16 vapier Exp $
  *
  * Copyright 2005-2008 Ned Ludd        - <solar@gentoo.org>
- * Copyright 2005-2008 Mike Frysinger  - <vapier@gentoo.org>
+ * Copyright 2005-2014 Mike Frysinger  - <vapier@gentoo.org>
  */
 
 const char * const booga[] = {"!!!", "!=", "==", ">", "<"};
@@ -61,6 +60,12 @@ static int atom_compare(const depend_atom *a1, const depend_atom *a2)
 			return NOT_EQUAL;
 	}
 
+	/* check repo */
+	if (a1->REPO || a2->REPO) {
+		if (!a1->REPO || !a2->REPO || strcmp(a1->REPO, a2->REPO))
+			return NOT_EQUAL;
+	}
+
 	/* Check category, iff both are specified.  This way we can match
 	 * atoms like "sys-devel/gcc" and "gcc".
 	 */
