@@ -3,40 +3,46 @@
 set -e
 
 if ! . /etc/init.d/functions.sh 2>/dev/null ; then
-	einfo() { echo " * $*"; }
-	eerror() { echo " * $*" 1>&2; }
+	einfo() { printf ' * %b\n' "$*"; }
+	eerror() { einfo "$@" 1>&2; }
 fi
+die() { eerror "$@"; exit 1; }
 
 v() { printf '\t%s\n' "$*"; "$@"; }
 
 : ${MAKE:=make}
 
 if [[ $# -ne 1 ]] ; then
-	eerror "Usage: $0 <ver>" 1>&2
-	exit 1
+	die "Usage: $0 <ver>"
 fi
 
-ver="$1"
-[[ "$ver" == "snap" ]] && ver=$(date -u +%Y%m%d)
-p="portage-utils-$ver"
+case $1 in
+snap) ver=$(date -u +%Y%m%d) ;;
+git) ver="HEAD" ;;
+*)
+	ver="v$1"
+	if ! git describe --tags "${ver}" >&/dev/null ; then
+		die "Please create the tag first: git tag ${ver}"
+	fi
+	;;
+esac
+p="portage-utils-${ver#v}"
 
 rm -rf "${p}"
 mkdir "${p}"
 
-einfo "Checking out clean cvs sources ..."
-cp -a CVS "${p}"/
+einfo "Checking out clean git sources ..."
+git archive "${ver}" | tar xf - -C "${p}"
 cd "${p}"
-v cvs -Q up
 
 einfo "Building autotools ..."
-sed -i "/^AC_INIT/s:cvs:${ver}:" configure.ac
+sed -i "/^AC_INIT/s:git:${ver}:" configure.ac
 sed -i "1iPV := ${ver}" Makefile
 LC_ALL=C ${MAKE} -s autotools >/dev/null
 rm -rf autom4te.cache
 cd ..
 
 einfo "Generating tarball ..."
-find "${p}" -type d -name CVS -prune -print0 | xargs -0 rm -rf
 tar cf - "${p}" | xz > "${p}".tar.xz
 rm -r "${p}"
 du -b "${p}".tar.*
