@@ -1,10 +1,9 @@
 /*
- * Copyright 2005-2013 Gentoo Foundation
+ * Copyright 2005-2014 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
- * $Header: /var/cvsroot/gentoo-projects/portage-utils/qdepends.c,v 1.66 2013/09/29 22:19:39 vapier Exp $
  *
  * Copyright 2005-2010 Ned Ludd        - <solar@gentoo.org>
- * Copyright 2005-2013 Mike Frysinger  - <vapier@gentoo.org>
+ * Copyright 2005-2014 Mike Frysinger  - <vapier@gentoo.org>
  */
 
 #ifdef APPLET_qdepends
@@ -32,7 +31,6 @@ static const char * const qdepends_opts_help[] = {
 	"Pretty format specified depend strings",
 	COMMON_OPTS_HELP
 };
-static const char qdepends_rcsid[] = "$Id: qdepends.c,v 1.66 2013/09/29 22:19:39 vapier Exp $";
 #define qdepends_usage(ret) usage(ret, QDEPENDS_FLAGS, qdepends_long_opts, qdepends_opts_help, lookup_applet_idx("qdepends"))
 
 static char qdep_name_only = 0;
@@ -358,14 +356,6 @@ void _dep_flatten_tree(const dep_node *root, char *buf, size_t *pos)
 	if (root->type == DEP_NULL) goto this_node_sucks;
 	if (root->type == DEP_NORM) {
 		size_t len = strlen(root->info);
-#if 1
-		if (*root->info == 'v')
-			if (strncmp(root->info, "virtual/", 8) == 0) {
-				if (virtuals == NULL)
-					virtuals = resolve_virtuals();
-				IF_DEBUG(fprintf(stderr, "(%s->%s)", root->info, virtual(root->info, virtuals)));
-			}
-#endif
 		memcpy(buf + *pos, root->info, len);
 		*pos += len+1;
 		buf[*pos-1] = ' ';
@@ -406,7 +396,8 @@ _q_static int qdepends_main_vdb_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 	int i;
 	char *ptr;
 	char buf[_Q_PATH_MAX];
-	char depend[65536], use[8192];
+	static char *depend, *use;
+	static size_t depend_len, use_len;
 	dep_node *dep_tree;
 
 	/* see if this cat/pkg is requested */
@@ -422,7 +413,7 @@ _q_static int qdepends_main_vdb_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 
 	IF_DEBUG(warn("matched %s/%s", catname, pkgname));
 
-	if (!eat_file_at(pkg_ctx->fd, state->depend_file, depend, sizeof(depend)))
+	if (!q_vdb_pkg_eat(pkg_ctx, state->depend_file, &depend, &depend_len))
 		return 0;
 
 	IF_DEBUG(warn("growing tree..."));
@@ -443,7 +434,7 @@ _q_static int qdepends_main_vdb_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 		printf("%s%s/%s%s%s: ", BOLD, catname, BLUE, pkgname, NORM);
 	}
 
-	if (!eat_file_at(pkg_ctx->fd, "USE", use, sizeof(use))) {
+	if (!q_vdb_pkg_eat(pkg_ctx, "USE", &use, &use_len)) {
 		warn("Could not eat_file(%s), you'll prob have incorrect output", buf);
 	} else {
 		for (ptr = use; *ptr; ++ptr)
@@ -476,12 +467,13 @@ _q_static int qdepends_vdb_deep_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 	size_t len;
 	char *ptr;
 	char buf[_Q_PATH_MAX];
-	char depend[16384], use[8192];
+	static char *depend, *use;
+	static size_t depend_len, use_len;
 	dep_node *dep_tree;
 
 	IF_DEBUG(warn("matched %s/%s for %s", catname, pkgname, state->depend_file));
 
-	if (!eat_file_at(pkg_ctx->fd, state->depend_file, depend, sizeof(depend)))
+	if (!q_vdb_pkg_eat(pkg_ctx, state->depend_file, &depend, &depend_len))
 		return 0;
 
 	IF_DEBUG(warn("growing tree..."));
@@ -491,7 +483,7 @@ _q_static int qdepends_vdb_deep_cb(q_vdb_pkg_ctx *pkg_ctx, void *priv)
 	IF_DEBUG(puts(depend));
 	IF_DEBUG(dep_dump_tree(dep_tree));
 
-	if (eat_file_at(pkg_ctx->fd, "USE", use, sizeof(use)) == 1)
+	if (q_vdb_pkg_eat(pkg_ctx, "USE", &use, &use_len))
 		use[0] = ' ';
 
 	for (ptr = use; *ptr; ++ptr)
